@@ -13,7 +13,7 @@ from keyword import iskeyword
 import attr
 import pycodestyle
 
-__version__ = "23.1.14"
+__version__ = "23.1.20"
 
 LOG = logging.getLogger("flake8.bugbear")
 CONTEXTFUL_NODES = (
@@ -450,7 +450,7 @@ class BugBearVisitor(ast.NodeVisitor):
         self.generic_visit(node)
 
     def visit_JoinedStr(self, node):
-        self.check_for_b028(node)
+        self.check_for_b907(node)
         self.generic_visit(node)
 
     def check_for_b005(self, node):
@@ -534,16 +534,14 @@ class BugBearVisitor(ast.NodeVisitor):
 
         if (
             hasattr(item_context, "func")
+            and isinstance(item_context.func, ast.Attribute)
             and (
-                (
-                    hasattr(item_context.func, "attr")
-                    and item_context.func.attr == "assertRaises"
-                )
+                item_context.func.attr == "assertRaises"
                 or (
-                    isinstance(item_context.func, ast.Attribute)
-                    and item_context.func.attr == "raises"
+                    item_context.func.attr == "raises"
                     and isinstance(item_context.func.value, ast.Name)
                     and item_context.func.value.id == "pytest"
+                    and "match" not in [kwd.arg for kwd in item_context.keywords]
                 )
             )
             and len(item_context.args) == 1
@@ -723,6 +721,7 @@ class BugBearVisitor(ast.NodeVisitor):
         if not any(map(is_abc_class, (*node.bases, *node.keywords))):
             return
 
+        has_method = False
         has_abstract_method = False
 
         for stmt in node.body:
@@ -735,6 +734,7 @@ class BugBearVisitor(ast.NodeVisitor):
             # only check function defs
             if not isinstance(stmt, (ast.FunctionDef, ast.AsyncFunctionDef)):
                 continue
+            has_method = True
 
             has_abstract_decorator = any(
                 map(is_abstract_decorator, stmt.decorator_list)
@@ -751,7 +751,7 @@ class BugBearVisitor(ast.NodeVisitor):
                     B027(stmt.lineno, stmt.col_offset, vars=(stmt.name,))
                 )
 
-        if not has_abstract_method:
+        if has_method and not has_abstract_method:
             self.errors.append(B024(node.lineno, node.col_offset, vars=(node.name,)))
 
     def check_for_b026(self, call: ast.Call):
@@ -997,12 +997,29 @@ class BugBearVisitor(ast.NodeVisitor):
         if not node.name.startswith("visit_"):
             return
 
-        # extract what's visited, only error if it's a valid ast subclass
-        # with a non-empty _fields attribute - which is what's iterated over in
-        # ast.NodeVisitor.generic_visit
+        # extract what's visited
         class_name = node.name[len("visit_") :]
         class_type = getattr(ast, class_name, None)
-        if class_type is None or not getattr(class_type, "_fields", None):
+
+        if (
+            # not a valid ast subclass
+            class_type is None
+            # doesn't have a non-empty '_fields' attribute - which is what's
+            # iterated over in ast.NodeVisitor.generic_visit
+            or not getattr(class_type, "_fields", None)
+            # or can't contain any ast subnodes that could be visited
+            # See https://docs.python.org/3/library/ast.html#abstract-grammar
+            or class_type.__name__
+            in (
+                "alias",
+                "Constant",
+                "Global",
+                "MatchSingleton",
+                "MatchStar",
+                "Nonlocal",
+                "TypeIgnore",
+            )
+        ):
             return
 
         for n in itertools.chain.from_iterable(ast.walk(nn) for nn in node.body):
@@ -1014,7 +1031,7 @@ class BugBearVisitor(ast.NodeVisitor):
         else:
             self.errors.append(B906(node.lineno, node.col_offset))
 
-    def check_for_b028(self, node: ast.JoinedStr):  # noqa: C901
+    def check_for_b907(self, node: ast.JoinedStr):  # noqa: C901
         # AST structure of strings in f-strings in 3.7 is different enough this
         # implementation doesn't work
         if sys.version_info <= (3, 7):
@@ -1048,7 +1065,7 @@ class BugBearVisitor(ast.NodeVisitor):
                 and value.value[0] == current_mark
             ):
                 self.errors.append(
-                    B028(
+                    B907(
                         variable.lineno,
                         variable.col_offset,
                         vars=(myunparse(variable.value),),
@@ -1411,11 +1428,12 @@ B016 = Error(
 )
 B017 = Error(
     message=(
-        "B017 assertRaises(Exception): or pytest.raises(Exception) should "
-        "be considered evil. It can lead to your test passing even if the "
-        "code being tested is never executed due to a typo. Either assert "
-        "for a more specific exception (builtin or custom), use "
-        "assertRaisesRegex, or use the context manager form of assertRaises."
+        "B017 `assertRaises(Exception)` and `pytest.raises(Exception)` should "
+        "be considered evil. They can lead to your test passing even if the "
+        "code being tested is never executed due to a typo. Assert for a more "
+        "specific exception (builtin or custom), or use `assertRaisesRegex` "
+        "(if using `assertRaises`), or add the `match` keyword argument (if "
+        "using `pytest.raises`), or use the context manager form with a target."
     )
 )
 B018 = Error(
@@ -1460,8 +1478,9 @@ B022 = Error(
 B023 = Error(message="B023 Function definition does not bind loop variable {!r}.")
 B024 = Error(
     message=(
-        "B024 {} is an abstract base class, but it has no abstract methods. Remember to"
-        " use the @abstractmethod decorator, potentially in conjunction with"
+        "B024 {} is an abstract base class, but none of the methods it defines are"
+        " abstract. This is not necessarily an error, but you might have forgotten to"
+        " add the @abstractmethod decorator, potentially in conjunction with"
         " @classmethod, @property and/or @staticmethod."
     )
 )
@@ -1485,12 +1504,6 @@ B027 = Error(
         " decorator. Consider adding @abstractmethod."
     )
 )
-B028 = Error(
-    message=(
-        "B028 {!r} is manually surrounded by quotes, consider using the `!r` conversion"
-        " flag."
-    )
-)
 
 # Warnings disabled by default.
 B901 = Error(
@@ -1539,6 +1552,13 @@ B906 = Error(
     )
 )
 
+B907 = Error(
+    message=(
+        "B907 {!r} is manually surrounded by quotes, consider using the `!r` conversion"
+        " flag."
+    )
+)
+
 B950 = Error(message="B950 line too long ({} > {} characters)")
 
 disabled_by_default = ["B901", "B902", "B903", "B904", "B905", "B906", "B950"]
